(define-module (ui mirror repository ajax)
	       :use-module (alterator ajax)
	       :use-module (alterator woo)
	       :export (init))

(define (validate-mirror)
  (catch #t
    (lambda()
      (woo "validate_mirror" "/mirror" 'mirror (form-value "mirror"))
      #t)
    (lambda args #f)))

(define (update-mirror)
  (form-update-visibility "custom_url" (string=? (form-value "mirror") "custom"))
  (form-update-activity "local" (validate-mirror)))

(define *parameters* '("description" "arch" "mirror" "custom_url" "local" "publish"))

(define (ui-read)
  (catch/message
    (lambda()
      (let* ((language (form-value "language"))
	     (name (form-value "name"))
	     (mirror-list (woo-list "/mirror/avail_mirror" 'language language 'name name))
	     (arch-list (woo-list "/mirror/avail_arch" 'language language 'name name))
	     (data (woo-read-first "/mirror/repository" 'language language 'name name))
	     (mirror (woo-get-option data 'mirror)))
	(form-update-enum "mirror" mirror-list)
	(form-update-enum "arch" arch-list)
	(form-update-value-list *parameters* data)
	;; default mirror if we need it
	(and (string-null? mirror)
	     (pair? mirror-list)
	     (form-update-value "mirror" (woo-get-option (car mirror-list) 'name)))
	(update-mirror)))))

(define (ui-return)
  (form-replace "/mirror"))

(define (ui-write)
  (catch/message
    (lambda()
      (apply woo-write "/mirror/repository/"
	     'commit #t
	     'name (form-value "name")
	     'language (form-value "language")
	     (form-value-list *parameters*))
      (ui-return))))

(define (ui-clear)
  (and (form-confirm (_ "Are really want to clear local repository?") (_ "Question") (_ "Yes") (_ "No"))
       (catch/message
	 (lambda()
	   (apply woo-write "/mirror/repository/"
		  'clear #t
		  'name (form-value "name")
		  'language (form-value "language")
		  (form-value-list *parameters*))
	   (ui-return)))))

(define (init)
  (ui-read)
  (form-bind "mirror" "change" update-mirror)
  (form-bind "apply" "click" ui-write)
  (form-bind "reset" "click" ui-read)
  (form-bind "clear" "click" ui-clear))

